#
# spec file
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# ninja too old on openSUSE Leap 15.1
%if 0%{?suse_version} == 1500 && 0%{?sle_version} == 150100
%bcond_with ninja
%else
%global __builder ninja
%bcond_without ninja
%endif

%global flavor openmpi4%{nil}

%define sover 7
%global shlib lib%{name}%{sover}
%define srcname casacore

# SECTION MPI DEFINITIONS
%if "%{flavor}" == "openmpi4"
%global mpi_flavor openmpi
%define mpi_vers 4
%endif

%if "%{flavor}" == "openmpi5"
%global mpi_flavor openmpi
%define mpi_vers 5
%endif

%{?mpi_flavor:%{bcond_without mpi}}%{!?mpi_flavor:%{bcond_with mpi}}
%{?with_mpi:%{!?mpi_flavor:error "No MPI family specified!"}}

%if %{with mpi}
%define my_prefix  %{_libdir}/mpi/gcc/%{mpi_flavor}%{?mpi_vers}
%define my_bindir  %{my_prefix}/bin
%define my_libdir  %{my_prefix}/%{_lib}
%define my_incdir  %{my_prefix}/include
%define my_datadir %{my_prefix}/share
%define my_suffix  -%{mpi_flavor}%{?mpi_vers}
%else
%define my_prefix  %{_prefix}
%define my_bindir  %{_bindir}
%define my_libdir  %{_libdir}
%define my_incdir  %{_includedir}
%define my_datadir %{_datadir}
%endif
# /SECTION MPI DEFINITIONS

# SECTION PKG NAMING DEFINITIONS
%define pname %{srcname}%{?my_suffix}
%define shlib lib%{srcname}%{sover}%{?my_suffix}
# /SECTION

Name:           %{pname}
Version:        3.5.0
Release:        5.1
Summary:        A suite of C++ libraries for radio astronomy data processing
License:        LGPL-2.0-or-later
URL:            https://github.com/casacore/casacore
Source:         https://github.com/casacore/casacore/archive/v%{version}.tar.gz#/%{srcname}-%{version}.tar.gz
Source99:       casacore-rpmlintrc
# PATCH-FIX-UPSTREAM casacore-fitsio-header.patch badshah400@gmail.com -- Fix location of cfitsio headers used in sources
Patch1:         casacore-fitsio-header.patch
# PATCH-FIX-UPSTREAM casacore-mirlib-gcc14-compat.patch gh#casacore/casacore#1344 badshah400@gmail.com -- Fix builds against GCC 14; patch taken from upstream commit
Patch2:         https://github.com/casacore/casacore/commit/a4516a86f935dea17502727c34f91955b73209ef.patch#/casacore-mirlib-gcc14-compat.patch
BuildRequires:  bison
BuildRequires:  blas-devel
BuildRequires:  cmake
BuildRequires:  fftw3-threads-devel
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  hdf5%{?my_suffix}-devel
BuildRequires:  lapack-devel
BuildRequires:  libboost_headers-devel
BuildRequires:  libboost_python3-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-devel
BuildRequires:  python3-numpy-devel
BuildRequires:  readline-devel
BuildRequires:  pkgconfig(cfitsio)
BuildRequires:  pkgconfig(fftw3)
BuildRequires:  pkgconfig(gsl)
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(wcslib)
BuildRequires:  pkgconfig(zlib)
%if %{with mpi}
BuildRequires:  %{mpi_flavor}%{?mpi_vers}-config
BuildRequires:  %{mpi_flavor}%{?mpi_vers}-devel
BuildRequires:  fftw3-openmp-devel
%endif
%if %{with ninja}
BuildRequires:  ninja
%endif

%description
Casacore provides a suite of C++ libraries for radio astronomy data processing.

%package -n %{shlib}
Summary:        Shared libraries for casacore, a suite of radio astronomy data

%description -n %{shlib}
Casacore provides a suite of C++ libraries for radio astronomy data processing.

This package provides the shared libraries for casacore.

%package devel
Summary:        Headers and sources for developing with casacore
Requires:       %{shlib} = %{version}
Requires:       gsl-devel
Requires:       hdf5-devel
Requires:       lapack-devel
Requires:       libboost_python3-devel
Requires:       readline-devel
Requires:       pkgconfig(cfitsio)
Requires:       pkgconfig(fftw3)
Requires:       pkgconfig(ncurses)
Requires:       pkgconfig(wcslib)

%description devel
Casacore provides a suite of C++ libraries for radio astronomy data processing.

This package provides the headers and sources for developing software with casacore.

%prep
%autosetup -p1 -n %{srcname}-%{version}

%build
%if %{with mpi}
source %{my_bindir}/mpivars.sh
export CC=mpicc
export CXX=mpicxx
%else
export CC=gcc
export CXX=g++
%endif

export CFLAGS="%{optflags}"
export CXXFLAGS="%{optflags}"
%cmake \
  -DCMAKE_INSTALL_PREFIX:PATH=%{my_prefix} \
  -DUSE_FFTW3:BOOL=ON \
  -DDATA_DIR:PATH=%{my_datadir}/casacore/data \
  -DPORTABLE:BOOL=ON \
  -DUSE_OPENMP:BOOL=ON \
  -DUSE_MPI:BOOL=%{?with_mpi:ON}%{!?with_mpi:OFF} \
  -DUSE_HDF5:BOOL=ON \
  -DBUILD_PYTHON:BOOL=OFF \
  -DBUILD_PYTHON3:BOOL=ON \
  -DENABLE_SHARED:BOOL=ON \
  -DENABLE_RPATH:BOOL=OFF \
  -DUSE_THREADS:BOOL=ON

%cmake_build

%install
%cmake_install

# Move pkgconfig file to arch-specific libdir
if [ "%{_lib}" != "lib" ]
then
mkdir -p %{buildroot}%{my_libdir}/pkgconfig/
mv %{buildroot}%{my_prefix}/lib/pkgconfig/*.pc %{buildroot}%{my_libdir}/pkgconfig/
fi

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files
%{my_bindir}/*

%files -n %{shlib}
%{my_libdir}/*.so.%{sover}

%files devel
%license COPYING
%doc CHANGES.md README.md
%{my_libdir}/*.so
%{my_libdir}/pkgconfig/*.pc
%{my_incdir}/casacore/

%changelog
* Wed May 22 2024 Atri Bhattacharya <badshah400@gmail.com>
- Drop casacore-drop-mirlib.patch: Superseded in favour of better
  patch casacore-mirlib-gcc14-compat.patch already committed
  upstream.
- Add casacore-mirlib-gcc14-compat.patch: Resolve issues compiling
  mirlib with gcc 14 (gh#casacore/casacore#1344,
  gh#casacore/casacore#1353).
* Thu May  2 2024 Atri Bhattacharya <badshah400@gmail.com>
- Add casacore-drop-mirlib.patch: drop unused mirlib library,
  patch taken from upstream PR. Fixes build failures against
  GCC-14 (gh#casacore/casacore#1344).
* Mon Oct 23 2023 Nicolas Morey <nicolas.morey@suse.com>
- Drop support for obsolete openmpi[123]
- Prepare support for openmpi5
* Tue Jul 19 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Avoid compile-time CPU-detection (boo#1100677)
* Tue Jul  5 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.5.0:
  * TaQL now supports copying columns to new columns (e.g. to make
    a backup of the FLAG column)
  * Non-zero coordinates in JPL frames, e.g. the SUN frame, are
    now interpreted as an offset in right ascension and
    declination. Previously, coordinates in a JPL coordinate frame
    were ignored.
  * The Dysco storage manager is now built by default as part of
    casacore.
  * General:
  - Modernizations: remove Mutex (gh#casacore/casacore#1095,
    gh#casacore/casacore#1127, gh#casacore/casacore#1128),
    typing system (gh#casacore/casacore#1172,
    gh#casacore/casacore#1176).
  - Allow building with newer compilers
    (gh#casacore/casacore#1134, gh#casacore/casacore#1137,
    gh#casacore/casacore#1145, gh#casacore/casacore#1206,
    gh#casacore/casacore#1208, gh#casacore/casacore#1210,
    gh#casacore/casacore#1211).
  - Build python3 by default, not python2
    (gh#casacore/casacore#1209).
  * MeasurementSet:
  - Improve reading of DataDescriptionId
    (gh#casacore/casacore#1103).
  - Compute feed information (gh#casacore/casacore#1104) and
    field attributes (gh#casacore/casacore#1109) on demand.
  - UVFits improvements: support X-Y mounts
    (gh#casacore/casacore#1115), allow large antenna numbers
    (gh#casacore/casacore#1144), fix handling FITS-IDI
    GAIN_CURVE (gh#casacore/casacore#1151).
  - Fix precision in T+dT syntax (gh#casacore/casacore#1118).
  * Measures Allow offsets to JPL coordinates
    (gh#casacore/casacore#1160).
  * Tables:
  - Cache iteration boundaries while sorting tables
    (gh#casacore/casacore#1106).
  - Use RefTable for iteration (gh#casacore/casacore#1108).
  - Adios2 related changes: gh#casacore/casacore#1110,
    gh#casacore/casacore#1116, gh#casacore/casacore#1121,
    gh#casacore/casacore#1148.
  - Make Dysco part of casacore (gh#casacore/casacore#1117,
    gh#casacore/casacore#1125, gh#casacore/casacore#1146,
    gh#casacore/casacore#1166).
  - Add TaQL commands LIKE, COPYCOLUMN and DROPTABLE
    (gh#casacore/casacore#1154, gh#casacore/casacore#1169).
  - Fix one bug in rownr_t migration for TiledDataStMan
    (gh#casacore/casacore#1156).
  - Improve documentation (gh#casacore/casacore#1192).
  * Images:
  - Support CARTA opening images with a custom handler
    (gh#casacore/casacore#1158).
  - Allow easier python handling of beams
    (gh#casacore/casacore#1184).
- Drop upstreamed patches:
  * 1129.patch.
  * casacore-link-math.patch.
- New BuildRequires: gsl-devel and libboost_headers-devel.
- Move installed pkgconfig file to correct arch dependent
  location.
* Fri Apr 29 2022 Atri Bhattacharya <badshah400@gmail.com>
- Add casacore-link-math.patch: Explicitly link to math library
  when building mirlab [gh#casacore/casacore#1190].
- Drop ExcludeArch: %%ix86 to allow building for related 32-bit
  systems in light of previous commit (Fri Mar 11 10:04:22 UTC
  2022).
* Wed Apr 27 2022 Jan Engelhardt <jengelh@inai.de>
- Add an rpmlintrc for shlib-policy-name-error
* Fri Mar 11 2022 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add upstream patch to fix build on 32-bit architectures:
  * 1129.patch
* Thu Feb 25 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 3.4.0:
  * Major modernization of Arrays, bringing it more in line with
    C++11 (gh#casacore/casacore#1012).
  * Use std::regex (gh#casacore/casacore#1072).
  * Remove many warnings (gh#casacore/casacore#1024,
    gh#casacore/casacore#1036, gh#casacore/casacore#1062).
  * Use FFTW as default FFT provider (gh#casacore/casacore#1029,
    gh#casacore/casacore#1047, gh#casacore/casacore#1049).
  * UVFITS improvements (gh#casacore/casacore#1033,
    gh#casacore/casacore#1040, gh#casacore/casacore#1064,
    gh#casacore/casacore#1066, gh#casacore/casacore#1067).
  * Support for 64-bit row numbers.
- Drop patches incorporated upstream:
  * casacore-drop-fftpak.patch
  * casacore-lawson_f-fortran-errors.patch
- Bump so version in shared lib name.
- 32-bit builds not supported, use ExcludeArch to prevent build
  failures.
* Mon Aug 17 2020 Michel Normand <normand@linux.vnet.ibm.com>
- Add _constraints with 5GB min disk space to avoid build failure
  for ppc64,ppc64le, s390x architectures.
* Thu Aug  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Add casacore-drop-fftpak.patch: Drop fftpak as it no longer
  compiles with recent gcc-fortran; taken from upstream commits.
- Add casacore-lawson_f-fortran-errors.patch: Fix fortran errors
  and warnings with lawson_f; taken from upstream commits.
- Add casacore-fitsio-header.patch: Fix location of cfitsio
  headers used in sources.
* Thu Aug  6 2020 Atri Bhattacharya <badshah400@gmail.com>
- Initial package.
